==> ui-18.0.3.tgz: package/components/tree/SearchPanel.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useImperativeHandle, useMemo, useRef } from 'react';
import { useEventCallback } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { DCheckbox } from '../checkbox';
import { usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
import { getText, TREE_NODE_KEY } from './utils';
function SearchPanel(props, ref) {
    const { dGetItemId, dList, dFocusItem, dCustomItem, dMultiple, dOnlyLeafSelectable, dFocusVisible, onFocusChange, onClickItem } = props, restProps = __rest(props, ["dGetItemId", "dList", "dFocusItem", "dCustomItem", "dMultiple", "dOnlyLeafSelectable", "dFocusVisible", "onFocusChange", "onClickItem"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const vsRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const handleKeyDown = useEventCallback((key) => {
        var _a, _b, _c, _d;
        const focusItem = (item) => {
            if (item) {
                onFocusChange(item);
            }
        };
        switch (key) {
            case 'next':
                focusItem((_a = vsRef.current) === null || _a === void 0 ? void 0 : _a.scrollToStep(1));
                break;
            case 'prev':
                focusItem((_b = vsRef.current) === null || _b === void 0 ? void 0 : _b.scrollToStep(-1));
                break;
            case 'first':
                focusItem((_c = vsRef.current) === null || _c === void 0 ? void 0 : _c.scrollToStart());
                break;
            case 'last':
                focusItem((_d = vsRef.current) === null || _d === void 0 ? void 0 : _d.scrollToEnd());
                break;
            case 'click':
                if (dFocusItem) {
                    onClickItem(dFocusItem);
                }
                break;
            default:
                break;
        }
    });
    useImperativeHandle(ref, () => handleKeyDown, [handleKeyDown]);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemKey: (item) => item.value,
        dFocusable: (item) => item[TREE_NODE_KEY].enabled,
    }), [dList]);
    return (_jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria }) => {
            const node = item[TREE_NODE_KEY];
            let inSelected = node.checked;
            if (!dOnlyLeafSelectable) {
                let _node = node;
                while (_node.parent) {
                    _node = _node.parent;
                    if (_node.id === item.value) {
                        inSelected = true;
                        break;
                    }
                }
            }
            return (_createElement("li", Object.assign({}, aria, { key: item.value, id: dGetItemId(item.value), className: getClassName(`${dPrefix}tree__search-option`, {
                    'is-selected': !dMultiple && inSelected,
                    'is-disabled': node.disabled,
                }), title: item.label, role: "option", "aria-selected": node.checked, "aria-disabled": node.disabled, onClick: () => {
                    onFocusChange(item);
                    onClickItem(item);
                } }),
                dFocusVisible && (dFocusItem === null || dFocusItem === void 0 ? void 0 : dFocusItem.value) === item.value && _jsx("div", { className: `${dPrefix}focus-outline` }),
                dMultiple && _jsx(DCheckbox, { dModel: node.checked, dDisabled: node.disabled }),
                _jsx("div", Object.assign({ className: `${dPrefix}tree__search-option-content` }, { children: dCustomItem ? dCustomItem(node.origin) : getText(node) }))));
        }, dFocusItem: dFocusItem, dSize: 264, dPadding: 4 }, { children: ({ render, vsList }) => render(
        // eslint-disable-next-line jsx-a11y/aria-activedescendant-has-tabindex
        _jsx("ul", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}tree__search-list`), tabIndex: -1, role: "listbox", "aria-multiselectable": dMultiple, "aria-activedescendant": isUndefined(dFocusItem) ? undefined : dGetItemId(dFocusItem.value) }, { children: dList.length === 0 ? (_jsx("li", Object.assign({ className: `${dPrefix}tree__search-empty` }, { children: _jsx("div", Object.assign({ className: `${dPrefix}tree__search-option-content` }, { children: t('No Data') })) }))) : (vsList) }))) })));
}
export const DSearchPanel = React.forwardRef(SearchPanel);

==> ui-18.3.3.tgz: package/components/tree/SearchPanel.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React, { useImperativeHandle, useMemo, useRef } from 'react';
import { useEventCallback } from '@react-devui/hooks';
import { getClassName } from '@react-devui/utils';
import { DCheckbox } from '../checkbox';
import { usePrefixConfig, useTranslation } from '../root';
import { DVirtualScroll } from '../virtual-scroll';
import { getText, TREE_NODE_KEY } from './utils';
function SearchPanel(props, ref) {
    const { dGetItemId, dList, dFocusItem, dCustomItem, dMultiple, dOnlyLeafSelectable, dFocusVisible, dVirtual, onFocusChange, onClickItem } = props, restProps = __rest(props, ["dGetItemId", "dList", "dFocusItem", "dCustomItem", "dMultiple", "dOnlyLeafSelectable", "dFocusVisible", "dVirtual", "onFocusChange", "onClickItem"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const vsRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const handleKeyDown = useEventCallback((key) => {
        var _a, _b, _c, _d;
        const focusItem = (item) => {
            if (item) {
                onFocusChange(item);
            }
        };
        switch (key) {
            case 'next':
                focusItem((_a = vsRef.current) === null || _a === void 0 ? void 0 : _a.scrollToStep(1));
                break;
            case 'prev':
                focusItem((_b = vsRef.current) === null || _b === void 0 ? void 0 : _b.scrollToStep(-1));
                break;
            case 'first':
                focusItem((_c = vsRef.current) === null || _c === void 0 ? void 0 : _c.scrollToStart());
                break;
            case 'last':
                focusItem((_d = vsRef.current) === null || _d === void 0 ? void 0 : _d.scrollToEnd());
                break;
            case 'click':
                if (dFocusItem) {
                    onClickItem(dFocusItem);
                }
                break;
            default:
                break;
        }
    });
    useImperativeHandle(ref, () => handleKeyDown, [handleKeyDown]);
    const vsPerformance = useMemo(() => ({
        dList,
        dItemSize: 32,
        dItemKey: (item) => item.value,
        dFocusable: (item) => item[TREE_NODE_KEY].enabled,
    }), [dList]);
    return (_jsx(DVirtualScroll, Object.assign({}, vsPerformance, { ref: vsRef, dFillNode: _jsx("li", {}), dItemRender: (item, index, { aria }) => {
            const node = item[TREE_NODE_KEY];
            let inSelected = node.checked;
            if (!dOnlyLeafSelectable) {
                let _node = node;
                while (_node.parent) {
                    _node = _node.parent;
                    if (_node.id === item.value) {
                        inSelected = true;
                        break;
                    }
                }
            }
            return (_createElement("li", Object.assign({}, aria, { key: item.value, id: dGetItemId(item.value), className: getClassName(`${dPrefix}tree__search-option`, {
                    'is-selected': !dMultiple && inSelected,
                    'is-disabled': node.disabled,
                }), title: item.label, role: "option", "aria-selected": node.checked, "aria-disabled": node.disabled, onClick: () => {
                    onFocusChange(item);
                    onClickItem(item);
                } }),
                dFocusVisible && (dFocusItem === null || dFocusItem === void 0 ? void 0 : dFocusItem.value) === item.value && _jsx("div", { className: `${dPrefix}focus-outline` }),
                dMultiple && _jsx(DCheckbox, { dModel: node.checked, dDisabled: node.disabled }),
                _jsx("div", Object.assign({ className: `${dPrefix}tree__search-option-content` }, { children: dCustomItem ? dCustomItem(node.origin) : getText(node) }))));
        }, dFocusItem: dFocusItem, dSize: dVirtual ? 264 : Infinity, dPadding: 4 }, { children: ({ render, vsList }) => render(
        // eslint-disable-next-line jsx-a11y/aria-activedescendant-has-tabindex
        _jsx("ul", Object.assign({}, restProps, { className: getClassName(restProps.className, `${dPrefix}tree__search-list`), tabIndex: -1, role: "listbox", "aria-multiselectable": dMultiple, "aria-activedescendant": isUndefined(dFocusItem) ? undefined : dGetItemId(dFocusItem.value) }, { children: dList.length === 0 ? (_jsx("li", Object.assign({ className: `${dPrefix}tree__search-empty` }, { children: _jsx("div", Object.assign({ className: `${dPrefix}tree__search-option-content` }, { children: t('No Data') })) }))) : (vsList) }))) })));
}
export const DSearchPanel = React.forwardRef(SearchPanel);
